@@ -4,28 +4,28 @@
 #define DBUS_API_SUBJECT_TO_CHANGE
 #include <dbus/dbus.h>
 
-unsigned int dbind_find_c_alignment (char *type);
+unsigned int dbind_find_c_alignment (const char *type);
 
 void   dbind_any_marshal       (DBusMessageIter *iter,
-                                char           **type,
+                                const char           **type,
                                 void           **val);
 
 void   dbind_any_marshal_va    (DBusMessageIter *iter,
-                                char           **arg_types,
+                                const const char           **arg_types,
                                 va_list          args);
 
 void   dbind_any_demarshal     (DBusMessageIter *iter,
-                                char           **type,
+                                const char           **type,
                                 void           **val);
 
 void   dbind_any_demarshal_va  (DBusMessageIter *iter,
-                                char           **arg_types,
+                                const char           **arg_types,
                                 va_list          args);
 
-void   dbind_any_free          (char            *type,
+void   dbind_any_free          (const char      *type,
                                 void            *ptr_to_ptr);
 
-void   dbind_any_free_ptr      (char            *type,
+void   dbind_any_free_ptr      (const char      *type,
                                 void            *ptr);
 
 #endif /* _DBIND_ANY_H_ */
